@@ -21,13 +21,13 @@
 #define __GTT_APP_H__
 
 #include <gnome.h>
-#include "ctree.h"
-#include "ctree-gnome2.h"
 #include "notes-area.h"
 #include "proj.h"
+#include "status-icon.h"
+
 
-extern ProjTreeWindow *global_ptw;  /* global ptr to tree GUI window */
 extern NotesArea *global_na;        /* global ptr to notes GUI area */
+extern GttProjectsTree *projects_tree;
 
 extern GtkWidget *app_window;  /* global top-level window */
 extern GtkWidget *status_bar;
@@ -42,7 +42,7 @@ void app_new(int argc, char *argv[], const char *geometry_string);
 
 void app_show(void);
 void app_quit(GtkWidget *w, gpointer data);
-		  
+
 /* The ctree will call 'focus_row_set' whenever the focus row changes.
  * This is used in turn as a cheesey way  to re-distribute this event
  * to other subsystems.  Should be replaced ultimately by g_signals.
