@@ -307,10 +307,10 @@ gtt_load_gnome_config (const char *prefix)
 	_e = config_show_tb_exit;
 
 	/* get last running project */
-   cur_proj_id = GET_INT("/Misc/CurrProject=-1");
+	cur_proj_id = GET_INT("/Misc/CurrProject=-1");
 
-   config_idle_timeout = GET_INT("/Misc/IdleTimeout=300");
-   config_autosave_period = GET_INT("/Misc/AutosavePeriod=60");
+	config_idle_timeout = GET_INT("/Misc/IdleTimeout=300");
+	config_autosave_period = GET_INT("/Misc/AutosavePeriod=60");
 
 	/* Reset the main window width and height to the values
 	 * last stored in the config file.  Note that if the user
@@ -612,7 +612,7 @@ gtt_post_data_config (void)
 void
 gtt_post_ctree_config (void)
 {
-	const char * xpn = NULL;
+	gchar * xpn = NULL;
 
 	/* Assume the ctree has been set up.  Now punch in the final
 	 * bit of ctree state.
@@ -627,7 +627,10 @@ gtt_post_ctree_config (void)
 	{
 		xpn = gnome_config_get_string(GTT_CONF"/Display/ExpanderState");
 	}
-	gtt_projects_tree_set_expander_state (projects_tree, xpn);
+	if (xpn)
+	{
+		gtt_projects_tree_set_expander_state (projects_tree, xpn);
+	}
 }
 
 /* ======================================================= */
@@ -636,7 +639,7 @@ gtt_post_ctree_config (void)
 void
 gtt_save_config(void)
 {
-   gtt_gconf_save();
+	gtt_gconf_save();
 }
 
 /* ======================================================= */
