@@ -20,21 +20,20 @@
 
 #define _GNU_SOURCE
 #include <glib.h>
-#include <guile/gh.h>
+#include <libguile.h>
 #include <stdio.h>
 #include <string.h>
 
 #include <qof.h>
 
 #include "app.h"
-#include "ctree.h"
 #include "gtt.h"
 #include "ghtml.h"
 #include "ghtml-deprecated.h"
 #include "proj.h"
 #include "util.h"
 
-/* This file contains deprecated routines, which should go away 
+/* This file contains deprecated routines, which should go away
  * sometime in 2004 or 2005, around gnotime version 3.0 or so
  */
 
@@ -63,7 +62,7 @@ typedef enum {
 
 
 /* ============================================================== */
-/* This routine outputs a simple, hard-coded table showing the 
+/* This routine outputs a simple, hard-coded table showing the
  * project journal.  Its not terribly useful for use inside of
  * reports, but its a great place to understand how the other
  * code in this file works. */
@@ -77,10 +76,10 @@ do_show_journal (GttGhtml *ghtml, GttProject *prj)
 	char * ps;
 	gboolean show_links = ghtml->show_links;
 
-	if (NULL == ghtml->write_stream) return SCM_UNSPECIFIED;  
+	if (NULL == ghtml->write_stream) return SCM_UNSPECIFIED;
 
 	p = g_string_new(NULL);
-	g_string_append_printf (p, 
+	g_string_append_printf (p,
 		"<b>The use of this function is deprecated. "
 		" Please see the examples for the recommended style.</b>"
 		"<table border=1>\n"
@@ -100,7 +99,7 @@ do_show_journal (GttGhtml *ghtml, GttProject *prj)
 		
 		p = g_string_truncate (p, 0);
 		p = g_string_append (p, "<tr><td colspan=4>");
-		if (show_links) 
+		if (show_links)
 		{
 			g_string_append_printf (p, "<a href=\"gtt:task:0x%lx\">", (long)tsk);
 		}
@@ -123,30 +122,30 @@ do_show_journal (GttGhtml *ghtml, GttProject *prj)
 			elapsed = stop - start;
 			
 			p = g_string_truncate (p, 0);
-			p = g_string_append (p, 
+			p = g_string_append (p,
 				"<tr><td> &nbsp; &nbsp; &nbsp; </td>\n"
 				"<td align=right> &nbsp; &nbsp; ");
-			if (show_links) 
+			if (show_links)
 			{
 				g_string_append_printf (p, "<a href=\"gtt:interval:0x%lx\">", (long)ivl);
 			}
 
 			/* print hour only or date too? */
 			if (0 != prev_stop) {
-				prt_date = qof_is_same_day(start, prev_stop);
+				prt_date = xxxqof_is_same_day(start, prev_stop);
 			}
 			if (prt_date) {
-				qof_print_date_time_buff (buff, 100, start);
+				xxxqof_print_date_time_buff (buff, 100, start);
 				p = g_string_append (p, buff);
 			} else {
-				qof_print_time_buff (buff, 100, start);
+				xxxqof_print_time_buff (buff, 100, start);
 				p = g_string_append (p, buff);
 			}
 
 			/* print hour only or date too? */
-			prt_date = qof_is_same_day(start, stop);
+			prt_date = xxxqof_is_same_day(start, stop);
 			if (show_links) p = g_string_append (p, "</a>");
-			p = g_string_append (p, 
+			p = g_string_append (p,
 				" &nbsp; &nbsp; </td>\n"
 				"<td> &nbsp; &nbsp; ");
 			if (show_links)
@@ -154,10 +153,10 @@ do_show_journal (GttGhtml *ghtml, GttProject *prj)
 				g_string_append_printf (p, "<a href=\"gtt:interval:0x%lx\">", (long)ivl);
 			}
 			if (prt_date) {
-				qof_print_date_time_buff (buff, 100, stop);
+				xxxqof_print_date_time_buff (buff, 100, stop);
 				p = g_string_append (p, buff);
 			} else {
-				qof_print_time_buff (buff, 100, stop);
+				xxxqof_print_time_buff (buff, 100, stop);
 				p = g_string_append (p, buff);
 			}
 
@@ -165,7 +164,7 @@ do_show_journal (GttGhtml *ghtml, GttProject *prj)
 
 			if (show_links) p = g_string_append (p, "</a>");
 			p = g_string_append (p, " &nbsp; &nbsp; </td>\n<td> &nbsp; &nbsp; ");
-			qof_print_hours_elapsed_buff (buff, 100, elapsed, TRUE);
+			xxxqof_print_hours_elapsed_buff (buff, 100, elapsed, TRUE);
 			p = g_string_append (p, buff);
 			p = g_string_append (p, " &nbsp; &nbsp; </td></tr>\n");
 			(ghtml->write_stream) (ghtml, p->str, p->len, ghtml->user_data);
@@ -179,7 +178,7 @@ do_show_journal (GttGhtml *ghtml, GttProject *prj)
 	/* should the free-segment be false or true ??? */
 	g_string_free (p, FALSE);
 
-	return SCM_UNSPECIFIED;  
+	return SCM_UNSPECIFIED;
 }
 
 /* ============================================================== */
@@ -228,13 +227,13 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 	}
 	for (i=0; i<ghtml->ntask_cols; i++)
 	{
-		switch (ghtml->task_cols[i]) 
+		switch (ghtml->task_cols[i])
 		{
 			case MEMO:
 			{
 				int mcols;
 				mcols = ghtml->ninvl_cols - ghtml->ntask_cols;
-				if (0 >= mcols) mcols = 1; 
+				if (0 >= mcols) mcols = 1;
 				if (output_html) g_string_append_printf (p, "<th colspan=%d>", mcols);
 				TASK_COL_TITLE (_("Diary Entry"));
 				break;
@@ -282,7 +281,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 	for (i=0; i<ghtml->ninvl_cols; i++)
 	{
 		if (output_html) p = g_string_append (p, "<th>");
-		switch (ghtml->invl_cols[i]) 
+		switch (ghtml->invl_cols[i])
 		{
 			case START_DATIME:
 				INVL_COL_TITLE (_("Start"));
@@ -329,7 +328,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 		/* if we are in invoice mode, then skip anything not billable */
 		if (invoice)
 		{
-			if ((GTT_BILL != billstatus) || 
+			if ((GTT_BILL != billstatus) ||
 			    (GTT_NOT_BILLABLE == billable)) continue;
 		}
 
@@ -375,15 +374,15 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 		}
 		for (i=0; i<ghtml->ntask_cols; i++)
 		{
-			switch (ghtml->task_cols[i]) 
+			switch (ghtml->task_cols[i])
 			{
 				case MEMO:
 				{
 					int mcols;
 					mcols = ghtml->ninvl_cols - ghtml->ntask_cols;
-					if (0 >= mcols) mcols = 1; 
+					if (0 >= mcols) mcols = 1;
 					if (output_html) g_string_append_printf (p, "<td colspan=%d>", mcols);
-					if (show_links) 
+					if (show_links)
 					{
 						g_string_append_printf (p, "<a href=\"gtt:task:0x%lx\">", (long)tsk);
 					}
@@ -398,13 +397,13 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 					if (output_html) p = g_string_append (p, "<td align=left>");
 					pp = gtt_task_get_notes(tsk);
 					if (!pp || !pp[0]) pp = _("(empty)");
-					p = g_string_append (p, pp); 
+					p = g_string_append (p, pp);
 					break;
 
 				case TASK_TIME:
 					if (output_html) p = g_string_append (p, "<td align=right>");
-					qof_print_hours_elapsed_buff (buff, 100, task_secs, TRUE);
-					p = g_string_append (p, buff); 
+					xxxqof_print_hours_elapsed_buff (buff, 100, task_secs, TRUE);
+					p = g_string_append (p, buff);
 					break;
 
 				case BILLSTATUS:
@@ -500,9 +499,9 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 			elapsed = stop - start;
 
 			/* print hour only or date too? */
-			prt_stop_date = qof_is_same_day(start, stop);
+			prt_stop_date = xxxqof_is_same_day(start, stop);
 			if (0 != prev_stop) {
-				prt_start_date = qof_is_same_day(start, prev_stop);
+				prt_start_date = xxxqof_is_same_day(start, prev_stop);
 			}
 			prev_stop = stop;
 
@@ -513,7 +512,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 			for (i=0; i<ghtml->ninvl_cols; i++)
 			{
 
-				switch (ghtml->invl_cols[i]) 
+				switch (ghtml->invl_cols[i])
 				{
 	case START_DATIME:
 	{
@@ -523,10 +522,10 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 			g_string_append_printf (p, "<a href=\"gtt:interval:0x%lx\">", (long)ivl);
 		}
 		if (prt_start_date) {
-			qof_print_date_time_buff (buff, 100, start);
+			xxxqof_print_date_time_buff (buff, 100, start);
 			p = g_string_append (p, buff);
 		} else {
-			qof_print_time_buff (buff, 100, start);
+			xxxqof_print_time_buff (buff, 100, start);
 			p = g_string_append (p, buff);
 		}
 		if (show_links) p = g_string_append (p, "</a>");
@@ -541,10 +540,10 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 			g_string_append_printf (p, "<a href=\"gtt:interval:0x%lx\">", (long)ivl);
 		}
 		if (prt_stop_date) {
-			qof_print_date_time_buff (buff, 100, stop);
+			xxxqof_print_date_time_buff (buff, 100, stop);
 			p = g_string_append (p, buff);
 		} else {
-			qof_print_time_buff (buff, 100, stop);
+			xxxqof_print_time_buff (buff, 100, stop);
 			p = g_string_append (p, buff);
 		}
 		if (show_links) p = g_string_append (p, "</a>");
@@ -554,7 +553,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 	case ELAPSED:
 	{
 		if (output_html) p = g_string_append (p, "<td>&nbsp;&nbsp;");
-		qof_print_hours_elapsed_buff (buff, 100, elapsed, TRUE);
+		xxxqof_print_hours_elapsed_buff (buff, 100, elapsed, TRUE);
 		p = g_string_append (p, buff);
 		if (output_html) p = g_string_append (p, "&nbsp;&nbsp;");
 		break;
@@ -562,7 +561,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 	case FUZZ:
 	{
 		if (output_html) p = g_string_append (p, "<td>&nbsp;&nbsp;");
-		qof_print_hours_elapsed_buff (buff, 100, gtt_interval_get_fuzz(ivl), TRUE);
+		xxxqof_print_hours_elapsed_buff (buff, 100, gtt_interval_get_fuzz(ivl), TRUE);
 		p = g_string_append (p, buff);
 		if (output_html) p = g_string_append (p, "&nbsp;&nbsp;");
 		break;
@@ -575,7 +574,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 
 			if (output_html && (0<ghtml->ninvl_cols)) p = g_string_append (p, "</tr>\n");
 			p = g_string_append (p, ghtml->delim);
-			if (0 < p->len) 
+			if (0 < p->len)
 			{
 				(ghtml->write_stream) (ghtml, p->str, p->len, ghtml->user_data);
 			}
@@ -595,7 +594,7 @@ do_show_table (GttGhtml *ghtml, GttProject *prj, int invoice)
 
 /* ============================================================== */
 
-static SCM 
+static SCM
 gtt_hello (void)
 {
 	GttGhtml *ghtml = ghtml_guile_global_hack;
@@ -607,7 +606,7 @@ gtt_hello (void)
 	(ghtml->write_stream) (ghtml, p, strlen(p), ghtml->user_data);
 
 	/* maybe we should return something meaningful, like the string? */
-	return SCM_UNSPECIFIED;  
+	return SCM_UNSPECIFIED;
 }
 
 /* ============================================================== */
@@ -719,24 +718,23 @@ static SCM
 decode_scm_col_list (GttGhtml *ghtml, SCM col_list)
 {
 	SCM col_name;
-	int len;
 	char * tok = NULL;
 
 	/* reset the parser */
 	ghtml->ninvl_cols = 0;
 	ghtml->ntask_cols = 0;
 		
-	while (FALSE == SCM_NULLP(col_list))
+	while (!scm_is_null (col_list))
 	{
 		col_name = SCM_CAR (col_list);
 
 		/* either a 'symbol or a "quoted string" */
-		if (!SCM_SYMBOLP(col_name) && !SCM_STRINGP (col_name))
+		if (!scm_is_symbol(col_name) && !scm_is_string (col_name))
 		{
 			col_list = SCM_CDR (col_list);
 			continue;
 		}
-		tok = gh_scm2newstr (col_name, &len);
+		tok = scm_to_locale_string (col_name);
 		decode_column (ghtml, tok);
 
 		free (tok);
@@ -759,7 +757,7 @@ show_table (SCM col_list)
 {
 	GttGhtml *ghtml = ghtml_guile_global_hack;
 	SCM rc;
-	SCM_ASSERT ( SCM_CONSP (col_list), col_list, SCM_ARG1, "gtt-show-table");
+	SCM_ASSERT ( scm_is_pair (col_list), col_list, SCM_ARG1, "gtt-show-table");
 	rc = decode_scm_col_list (ghtml, col_list);
 	do_show_table (ghtml, ghtml->prj, FALSE);
 	return rc;
@@ -770,7 +768,7 @@ show_invoice (SCM col_list)
 {
 	GttGhtml *ghtml = ghtml_guile_global_hack;
 	SCM rc;
-	SCM_ASSERT ( SCM_CONSP (col_list), col_list, SCM_ARG1, "gtt-show-invoice");
+	SCM_ASSERT ( scm_is_pair (col_list), col_list, SCM_ARG1, "gtt-show-invoice");
 	rc = decode_scm_col_list (ghtml, col_list);
 	do_show_table (ghtml, ghtml->prj, TRUE);
 	return rc;
@@ -782,7 +780,7 @@ show_export (SCM col_list)
 	GttGhtml *ghtml = ghtml_guile_global_hack;
 	
 	SCM rc;
-	SCM_ASSERT ( SCM_CONSP (col_list), col_list, SCM_ARG1, "gtt-show-export");
+	SCM_ASSERT ( scm_is_pair (col_list), col_list, SCM_ARG1, "gtt-show-export");
 	rc = decode_scm_col_list (ghtml, col_list);
 	
 	ghtml->show_html = FALSE;
@@ -796,8 +794,8 @@ show_export (SCM col_list)
 }
 
 /* ============================================================== */
-/* Register callback handlers for various internally defined 
- * scheme forms. 
+/* Register callback handlers for various internally defined
+ * scheme forms.
  */
 
 static int depr_is_inited = 0;
