@@ -28,11 +28,9 @@
 #include <string.h>
 #include <sched.h>
 
-#include <qof/qof.h>
+#include <qof.h>
 
 #include "app.h"
-#include "ctree.h"
-#include "ctree-gnome2.h"
 #include "dialog.h"
 #include "journal.h"
 #include "ghtml.h"
@@ -290,6 +288,14 @@ static GList * cutted_task_list = NULL;
 /* ============================================================== */
 /* Interval Popup Menu actions */
 
+void
+edit_interval_close_cb (GtkWidget *edit_ivl, gpointer data)
+{
+	Wiggy *wig = (Wiggy *) data;
+	wig->edit_ivl = NULL;
+}
+
+
 static void
 interval_new_clicked_cb (GtkWidget * w, gpointer data)
 {
@@ -297,6 +303,8 @@ interval_new_clicked_cb (GtkWidget * w, gpointer data)
 
 	if (NULL == wig->edit_ivl) wig->edit_ivl = edit_interval_dialog_new();
 
+	edit_interval_set_close_callback (wig->edit_ivl, G_CALLBACK (edit_interval_close_cb), wig);
+
 	wig->interval = gtt_interval_new_insert_after(wig->interval);
 	edit_interval_set_interval (wig->edit_ivl, wig->interval);
 	edit_interval_dialog_show (wig->edit_ivl);
@@ -308,6 +316,7 @@ interval_edit_clicked_cb(GtkWidget * dw, gpointer data)
 	Wiggy *wig = (Wiggy *) data;
 
 	if (NULL == wig->edit_ivl) wig->edit_ivl = edit_interval_dialog_new();
+	edit_interval_set_close_callback (wig->edit_ivl, G_CALLBACK (edit_interval_close_cb), wig);
 	edit_interval_set_interval (wig->edit_ivl, wig->interval);
 	edit_interval_dialog_show (wig->edit_ivl);
 }
@@ -394,17 +403,17 @@ interval_paste_memo_cb(GtkWidget * w, gpointer data)
 	if (!cutted_task_list || !wig->interval) return;
 
 	/* Pop one off the stack, if stack has any depth to it */
-    if (NULL == cutted_task_list->next)
-    {
-    	newtask = gtt_task_copy (cutted_task_list->data);
-    }
-    else
-    {
-      newtask = cutted_task_list->data;
-      cutted_task_list->data = NULL;
-      cutted_task_list =
-        g_list_delete_link (cutted_task_list, cutted_task_list);
-    }
+	if (NULL == cutted_task_list->next)
+	{
+		newtask = gtt_task_copy (cutted_task_list->data);
+	}
+	else
+	{
+		newtask = cutted_task_list->data;
+		cutted_task_list->data = NULL;
+		cutted_task_list =
+		     g_list_delete_link (cutted_task_list, cutted_task_list);
+	}
 
 	gtt_interval_split (wig->interval, newtask);
 }
@@ -465,7 +474,7 @@ new_task_ui(GtkWidget *w, gpointer data)
 	GttProject *prj;
 	GttTask *newtask;
 
-	prj = ctree_get_focus_project (global_ptw);
+	prj = gtt_projects_tree_get_selected_project (projects_tree);
 	if (!prj) return;
 
 	newtask = gtt_task_new ();
@@ -481,7 +490,7 @@ edit_task_ui(GtkWidget *w, gpointer data)
 	GttProject *prj;
 	GttTask *task;
 
-	prj = ctree_get_focus_project (global_ptw);
+	prj = gtt_projects_tree_get_selected_project (projects_tree);
 	if (!prj) return;
 
 	task = gtt_project_get_first_task(prj);
@@ -551,11 +560,11 @@ task_paste_clicked_cb(GtkWidget * w, gpointer data)
 	if (!cutted_task_list || !wig->task) return;
 
 	/* Pop one off the stack, if stack has any depth to it */
-    newtask = cutted_task_list->data;
-    cutted_task_list->data = NULL;
-    cutted_task_list =
-      g_list_delete_link (cutted_task_list, cutted_task_list);
-    
+	newtask = cutted_task_list->data;
+	cutted_task_list->data = NULL;
+	cutted_task_list =
+	    g_list_delete_link (cutted_task_list, cutted_task_list);
+	
 	gtt_task_insert (wig->task, newtask);
 }
 
@@ -667,29 +676,27 @@ on_save_clicked_cb (GtkWidget *w, gpointer data)
 	GtkWidget *dialog;
 	Wiggy *wig = (Wiggy *) data;
 
-    dialog = gtk_file_chooser_dialog_new(_("Save HTML To File"),
-                                         GTK_WINDOW(wig->top),
-                                         GTK_FILE_CHOOSER_ACTION_SAVE,
-                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                         GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
-                                         NULL);
+	dialog = gtk_file_chooser_dialog_new(_("Save HTML To File"),
+	                                     GTK_WINDOW(wig->top),
+	                                     GTK_FILE_CHOOSER_ACTION_SAVE,
+	                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                     GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+	                                     NULL);
 
-    gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
+	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
 
-
-
-    /* Manually set a per-report history thingy */
-    if (wig->plg && wig->plg->last_url && (0==strncmp("file:/", wig->plg->last_url, 6)))
-    {
-      gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), wig->plg->last_url);
-    }
-    if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
-        char *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-        remember_uri (wig, filename);
-        save_to_file (wig, filename);
-        g_free(filename);
-    }
-    gtk_widget_destroy(GTK_WIDGET(dialog));
+	/* Manually set a per-report history thingy */
+	if (wig->plg && wig->plg->last_url && (0==strncmp("file:/", wig->plg->last_url, 6)))
+	{
+		gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), wig->plg->last_url);
+	}
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
+		  char *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
+		  remember_uri (wig, filename);
+		  save_to_file (wig, filename);
+		  g_free(filename);
+	}
+	gtk_widget_destroy(GTK_WIDGET(dialog));
 }
 
 static void
@@ -1042,6 +1049,8 @@ perform_form_query (KvpFrame *kvpf)
 
 	if (user_debug)
 	{
+		printf ("earliest-end-date = %s\n", kvp_frame_get_string (kvpf, "earliest-end-date"));
+		printf ("latest-start-date = %s\n", kvp_frame_get_string (kvpf, "latest-start-date"));
 		printf ("Debug: Will run the query %s\n", query_string);
 	}
 
@@ -1077,7 +1086,7 @@ submit_clicked_cb(GtkHTML * doc,
 	KvpValue *val;
 	GList *qresults;
 
-	if (!wig->prj) wig->prj = ctree_get_focus_project (global_ptw);
+	if (!wig->prj) wig->prj = gtt_projects_tree_get_selected_project (projects_tree);
 
 	kvpf = kvp_frame_new ();
 	kvp_frame_add_url_encoding (kvpf, encoding);
@@ -1368,7 +1377,7 @@ show_report (GtkWidget *w, gpointer data)
 	GttProject *prj;
 	char * path;
 
-	prj = ctree_get_focus_project (global_ptw);
+	prj = gtt_projects_tree_get_selected_project (projects_tree);
 
 	path = gtt_ghtml_resolve_path (report_file, NULL);
 	do_show_report (path, NULL, NULL, prj, FALSE, NULL);
@@ -1380,7 +1389,7 @@ invoke_report(GtkWidget *widget, gpointer data)
 	GttProject *prj;
 	GttPlugin *plg = data;
 
-	prj = ctree_get_focus_project (global_ptw);
+	prj = gtt_projects_tree_get_selected_project (projects_tree);
 
 	/* Do not gnome-filepath this, this is for user-defined reports */
 	do_show_report (plg->path, plg, NULL, prj, FALSE, NULL);
