@@ -34,7 +34,7 @@ struct NewPluginDialog_s
 	GladeXML  *gtxml;
 	GtkDialog *dialog;
 	GtkEntry  *plugin_name;
-	GnomeFileEntry  *plugin_path;
+	GtkFileChooser  *plugin_path;
 	GtkEntry  *plugin_tooltip;
 	GnomeApp  *app;
 };
@@ -79,7 +79,7 @@ gtt_plugin_copy (GttPlugin *orig)
 	return plg;
 }
 
-void 
+void
 gtt_plugin_free (GttPlugin *plg)
 {
 	if (!plg) return;
@@ -91,15 +91,15 @@ gtt_plugin_free (GttPlugin *plg)
 
 /* ============================================================ */
 
-static void 
+static void
 new_plugin_create_cb (GtkWidget * w, gpointer data)
 {
-	const char *title, *path, *tip;
+	const char *title, *tip;
 	NewPluginDialog *dlg = data;
 
 	/* Get the dialog contents */
 	title = gtk_entry_get_text (dlg->plugin_name);
-	path = gnome_file_entry_get_full_path (dlg->plugin_path, FALSE);
+	char* path = gtk_file_chooser_get_uri (dlg->plugin_path);
 	tip = gtk_entry_get_text (dlg->plugin_tooltip);
 
 	/* Do a basic sanity check */
@@ -111,9 +111,9 @@ new_plugin_create_cb (GtkWidget * w, gpointer data)
 	{
 		gchar *msg;
 		GtkWidget *mb;
-		msg = g_strdup_printf (_("Unable to open the report file %s\n"), path); 
+		msg = g_strdup_printf (_("Unable to open the report file %s\n"), path);
 		mb = gnome_message_box_new (msg,
-			GNOME_MESSAGE_BOX_ERROR, 
+			GNOME_MESSAGE_BOX_ERROR,
 			GTK_STOCK_CLOSE,
 			NULL);
 		gtk_widget_show (mb);
@@ -157,10 +157,11 @@ new_plugin_create_cb (GtkWidget * w, gpointer data)
 		gtk_entry_set_text (dlg->plugin_tooltip, "");
 		*/
 	}
+	g_free (path);
 	gtk_widget_hide (GTK_WIDGET(dlg->dialog));
 }
 
-static void 
+static void
 new_plugin_cancel_cb (GtkWidget * w, gpointer data)
 {
 	NewPluginDialog *dlg = data;
@@ -187,7 +188,7 @@ new_plugin_dialog_new (void)
 
 	glade_xml_signal_connect_data (gtxml, "on_ok_button_clicked",
 		GTK_SIGNAL_FUNC (new_plugin_create_cb), dlg);
-	  
+
 	glade_xml_signal_connect_data (gtxml, "on_cancel_button_clicked",
 		GTK_SIGNAL_FUNC (new_plugin_cancel_cb), dlg);
 
@@ -197,7 +198,7 @@ new_plugin_dialog_new (void)
 	dlg->plugin_name = GTK_ENTRY(e);
 
 	e = glade_xml_get_widget (gtxml, "plugin path");
-	dlg->plugin_path = GNOME_FILE_ENTRY(e);
+	dlg->plugin_path = GTK_FILE_CHOOSER(e);
 
 	e = glade_xml_get_widget (gtxml, "plugin tooltip");
 	dlg->plugin_tooltip = GTK_ENTRY(e);
@@ -209,14 +210,14 @@ new_plugin_dialog_new (void)
 
 /* ============================================================ */
 
-void 
+void
 new_plugin_dialog_show(NewPluginDialog *dlg)
 {
 	if (!dlg) return;
 	gtk_widget_show(GTK_WIDGET(dlg->dialog));
 }
 
-void 
+void
 new_plugin_dialog_destroy(NewPluginDialog *dlg)
 {
 	if (!dlg) return;
