@@ -25,8 +25,6 @@
 #include <string.h>
 
 #include "app.h"
-#include "ctree.h"
-#include "ctree-gnome2.h"
 #include "cur-proj.h"
 #include "dialog.h"
 #include "gtt.h"
@@ -88,7 +86,7 @@ int  config_currency_use_locale = 1;
 
 char * config_data_url = NULL;
 
-typedef struct _PrefsDialog 
+typedef struct _PrefsDialog
 {
 	GladeXML *gtxml;
 	GnomePropertyBox *dlg;
@@ -118,7 +116,7 @@ typedef struct _PrefsDialog
 
 	GtkCheckButton *logfileuse;
 	GtkWidget      *logfilename_l;
-	GtkEntry       *logfilename;
+	GtkFileChooser *logfilename;
 	GtkWidget      *logfilestart_l;
 	GtkEntry       *logfilestart;
 	GtkWidget      *logfilestop_l;
@@ -143,70 +141,140 @@ typedef struct _PrefsDialog
 	GtkEntry       *idle_secs;
 	GtkEntry       *no_project_secs;
 	GtkEntry       *daystart_secs;
-	GtkOptionMenu  *daystart_menu;
-	GtkOptionMenu  *weekstart_menu;
+	GtkComboBox  *daystart_menu;
+	GtkComboBox  *weekstart_menu;
 
-    GtkRadioButton *time_format_am_pm;
-    GtkRadioButton *time_format_24_hs;
-    GtkRadioButton *time_format_locale;
+	GtkRadioButton *time_format_am_pm;
+	GtkRadioButton *time_format_24_hs;
+	GtkRadioButton *time_format_locale;
 
-    GtkEntry       *currency_symbol;
-    GtkWidget      *currency_symbol_label;
-    GtkCheckButton *currency_use_locale;
+	GtkEntry       *currency_symbol;
+	GtkWidget      *currency_symbol_label;
+	GtkCheckButton *currency_use_locale;
 
 } PrefsDialog;
 
 
-/* ============================================================== */
-/** Get and set the nth menu item */
 
-static int
-get_optionmenu_item (GtkOptionMenu *opt_menu)
+/* Update the properties of the project view according to current settings */
+
+void
+prefs_update_projects_view (void)
 {
-	GList *node;
+	GList *columns = NULL;
 
-	/* Hunt for the selected item */
-	GtkWidget *menu = gtk_option_menu_get_menu (opt_menu);
-	int i=0;
-	GtkWidget *w = gtk_menu_get_active (GTK_MENU(menu));
-	for (node=GTK_MENU_SHELL(menu)->children; node; node=node->next)
+	if (config_show_title_importance)
 	{
-		if (w == node->data)
-		{
-			return i;
-		}
-		i++;
+		columns = g_list_insert (columns, "importance", -1);
 	}
-	return 0;  /* can't possible reach this ... */
+
+	if (config_show_title_urgency)
+	{
+		columns = g_list_insert (columns, "urgency", -1);
+	}
+	
+	if (config_show_title_status)
+	{
+		columns = g_list_insert (columns, "status", -1);
+	}
+
+	if (config_show_title_ever)
+	{
+		columns = g_list_insert (columns, "time_ever", -1);
+	}
+
+	if (config_show_title_year)
+	{
+		columns = g_list_insert (columns, "time_year", -1);
+	}
+
+	if (config_show_title_month)
+	{
+		columns = g_list_insert (columns, "time_month", -1);
+	}
+
+	if (config_show_title_week)
+	{
+		columns = g_list_insert (columns, "time_week", -1);
+	}
+
+	if (config_show_title_lastweek)
+	{
+		columns = g_list_insert (columns, "time_lastweek", -1);
+	}
+
+	if (config_show_title_yesterday)
+	{
+		columns = g_list_insert (columns, "time_yesterday", -1);
+	}
+
+	if (config_show_title_day)
+	{
+		columns = g_list_insert (columns, "time_today", -1);
+	}
+
+	if (config_show_title_current)
+	{
+		columns = g_list_insert (columns, "time_task", -1);
+	}
+
+	/* The title column is mandatory */
+	columns = g_list_insert (columns, "title", -1);
+
+	if (config_show_title_desc)
+	{
+		columns = g_list_insert (columns, "description", -1);
+	}
+
+	if (config_show_title_task)
+	{
+		columns = g_list_insert (columns, "task", -1);
+	}
+
+	if (config_show_title_estimated_start)
+	{
+		columns = g_list_insert (columns, "estimated_start", -1);
+	}
+
+	if (config_show_title_estimated_end)
+	{
+		columns = g_list_insert (columns, "estimated_end", -1);
+	}
+
+	if (config_show_title_due_date)
+	{
+		columns = g_list_insert (columns, "due_date", -1);
+	}
+
+	if (config_show_title_sizing)
+	{
+		columns = g_list_insert (columns, "sizing", -1);
+	}
+
+	if (config_show_title_percent_complete)
+	{
+		columns = g_list_insert (columns, "percent_done", -1);
+	}
+
+	gtt_projects_tree_set_visible_columns (projects_tree, columns);
+	g_list_free (columns);
+
+	gtk_tree_view_set_enable_tree_lines (GTK_TREE_VIEW (projects_tree),
+										 config_show_subprojects);
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (projects_tree),
+									   config_show_clist_titles);
 }
 
-static void 
-set_optionmenu_item (GtkOptionMenu *opt_menu, int item)
+void
+prefs_set_show_secs ()
 {
-	int i;
-	GList *node;
-	GtkWidget *w;
-	GtkMenuShell *menu;
-
-	/* Set the correct menu item based on current values */
-	w = gtk_option_menu_get_menu (opt_menu);
-	menu = GTK_MENU_SHELL(w);
-	i = 0;
-	for (node = menu->children; node; node=node->next)
-	{
-		if (item == i)
-		{
-			gtk_menu_shell_select_item (menu, node->data);
-			gtk_menu_shell_activate_item (menu, node->data, 1);
-			break;
-		}
-		i++;
-	}
+	gtt_projects_tree_set_show_seconds (projects_tree, config_show_secs);
 }
 
+
 /* ============================================================== */
-/** parse an HH:MM:SS string for the time returning seconds 
- * XXX should probably use getdate or fdate or something like that 
+/** parse an HH:MM:SS string for the time returning seconds
+ * XXX should probably use getdate or fdate or something like that
  */
 
 static int
@@ -241,7 +309,7 @@ scan_time_string (const char *str)
 
 /* ============================================================== */
 
-static void 
+static void
 toolbar_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
 {
 	int state;
@@ -288,7 +356,7 @@ toolbar_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
 }
 
 
-static void 
+static void
 prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 {
 	int state;
@@ -318,7 +386,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 
 		if (change)
 		{
-			ctree_refresh (global_ptw);
+			prefs_update_projects_view ();
 		}
 	
 	}
@@ -329,10 +397,11 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 		state = GTK_TOGGLE_BUTTON(odlg->show_secs)->active;
 		if (state != config_show_secs) {
 			config_show_secs = state;
-			ctree_setup (global_ptw, master_list);
+			prefs_set_show_secs ();
 			update_status_bar();
 			if (status_bar)
 			gtk_widget_queue_resize(status_bar);
+			start_main_timer ();
 		}
 		if (GTK_TOGGLE_BUTTON(odlg->show_statusbar)->active) {
 			gtk_widget_show(GTK_WIDGET(status_bar));
@@ -343,20 +412,16 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 		}
 		if (GTK_TOGGLE_BUTTON(odlg->show_clist_titles)->active) {
 			config_show_clist_titles = 1;
-			ctree_titles_show (global_ptw);
 		} else {
 			config_show_clist_titles = 0;
-			ctree_titles_hide (global_ptw);
 		}
 	
 		if (GTK_TOGGLE_BUTTON(odlg->show_subprojects)->active) {
 			config_show_subprojects = 1;
-			ctree_subproj_show (global_ptw);
 		} else {
 			config_show_subprojects = 0;
-			ctree_subproj_hide (global_ptw);
 		}
-
+		prefs_update_projects_view ();
 	}
 
 	if (2 == page)
@@ -370,7 +435,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 	{
 		/* log file options */
 		config_logfile_use = GTK_TOGGLE_BUTTON(odlg->logfileuse)->active;
-		ENTRY_TO_CHAR(odlg->logfilename, config_logfile_name);
+		config_logfile_name = gtk_file_chooser_get_filename (odlg->logfilename);
 		ENTRY_TO_CHAR(odlg->logfilestart, config_logfile_start);
 		ENTRY_TO_CHAR(odlg->logfilestop, config_logfile_stop);
 		config_logfile_min_secs = atoi (gtk_entry_get_text(odlg->logfileminsecs));
@@ -394,7 +459,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 		SHOW_CHECK (tb_help);
 		SHOW_CHECK (tb_exit);
 
-		if (change) 
+		if (change)
 		{
 			update_toolbar_sections();
 		}
@@ -408,43 +473,52 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 		config_idle_timeout = atoi(gtk_entry_get_text(GTK_ENTRY(odlg->idle_secs)));
 		config_no_project_timeout = atoi(gtk_entry_get_text(GTK_ENTRY(odlg->no_project_secs)));
 
+		if (timer_is_running ())
+		{
+			start_idle_timer ();
+		}
+		else
+		{
+			start_no_project_timer ();
+		}
+
 		/* Hunt for the hour-of night on which to start */
 		const char * buff = gtk_entry_get_text (odlg->daystart_secs);
 		int off = scan_time_string (buff);
 		SET_VAL (config_daystart_offset,off);
 
-		int day = get_optionmenu_item (odlg->weekstart_menu);
+		int day = gtk_combo_box_get_active (odlg->weekstart_menu);
 		SET_VAL (config_weekstart_offset, day);
 
 		if (change)
 		{
 			/* Need to recompute everything, including the bining */
 			gtt_project_list_compute_secs();
-			ctree_refresh (global_ptw);
+			gtt_projects_tree_update_all_rows (projects_tree);
 		}
 	}
 
-    if (6 == page)
-    {
-        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm)))
-        {
-            config_time_format = TIME_FORMAT_AM_PM;
-        }
-        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs)))
-        {
-            config_time_format = TIME_FORMAT_24_HS;
-        }
-        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale)))
-        {
-            config_time_format = TIME_FORMAT_LOCALE;
-        }
+	if (6 == page)
+	{
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm)))
+		{
+			config_time_format = TIME_FORMAT_AM_PM;
+		}
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs)))
+		{
+			config_time_format = TIME_FORMAT_24_HS;
+		}
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale)))
+		{
+			config_time_format = TIME_FORMAT_LOCALE;
+		}
 
-		  ENTRY_TO_CHAR(odlg->currency_symbol, config_currency_symbol);
-          int state = GTK_TOGGLE_BUTTON(odlg->currency_use_locale)->active;
-          if (config_currency_use_locale != state) {
-              config_currency_use_locale = state;
-          }
-    }
+		ENTRY_TO_CHAR(odlg->currency_symbol, config_currency_symbol);
+		int state = GTK_TOGGLE_BUTTON(odlg->currency_use_locale)->active;
+		if (config_currency_use_locale != state) {
+			 config_currency_use_locale = state;
+		}
+	}
 
 	/* Also save them the to file at this point */
 	save_properties();
@@ -452,7 +526,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 
 /* ============================================================== */
 
-static void 
+static void
 logfile_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
 {
 	int state;
@@ -468,7 +542,7 @@ logfile_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
 	gtk_widget_set_sensitive(odlg->logfileminsecs_l, state);
 }
 
-static void 
+static void
 currency_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
 {
 	int state;
@@ -483,7 +557,7 @@ currency_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->show_##TOK), \
 		config_show_##TOK);
 
-static void 
+static void
 options_dialog_set(PrefsDialog *odlg)
 {
 	char s[30];
@@ -524,9 +598,9 @@ options_dialog_set(PrefsDialog *odlg)
 	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->logfileuse), config_logfile_use);
 	if (config_logfile_name)
-		gtk_entry_set_text(odlg->logfilename, config_logfile_name);
+		gtk_file_chooser_set_filename (odlg->logfilename, config_logfile_name);
 	else
-		gtk_entry_set_text(odlg->logfilename, "");
+		gtk_file_chooser_unselect_all (odlg->logfilename);
 	
 	if (config_logfile_start)
 		gtk_entry_set_text(odlg->logfilestart, config_logfile_start);
@@ -577,45 +651,45 @@ options_dialog_set(PrefsDialog *odlg)
 	if (-3 > hour) hour = -3; /* menu runs from 9pm */
 	if (6 < hour) hour = 6;   /* menu runs till 6am */
 	hour += 3;  /* menu starts at 9PM */
-	set_optionmenu_item (odlg->daystart_menu, hour);
+	gtk_combo_box_set_active (odlg->daystart_menu, hour);
 
 	/* Print the daystart offset as a string in 24 hour time */
 	int secs = config_daystart_offset;
 	if (0 > secs) secs += 24*3600;
 	char buff[24];
-	qof_print_hours_elapsed_buff (buff, 24, secs, config_show_secs);   
+	xxxqof_print_hours_elapsed_buff (buff, 24, secs, config_show_secs);
 	gtk_entry_set_text (odlg->daystart_secs, buff);
 
 	/* Set the correct menu item based on current values */
 	int day = config_weekstart_offset;
-	set_optionmenu_item (odlg->weekstart_menu, day);
+	gtk_combo_box_set_active (odlg->weekstart_menu, day);
 
-    switch (config_time_format)
-    {
-    case TIME_FORMAT_AM_PM:
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm), TRUE);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs), FALSE);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale), FALSE);
-        break;
-    case TIME_FORMAT_24_HS:
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm), FALSE);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs), TRUE);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale), FALSE);
-        break;
-    
-    case TIME_FORMAT_LOCALE:
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm), FALSE);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs), FALSE);
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale), TRUE);
-        break;
-    
-    
-    }
+	switch (config_time_format)
+	{
+	case TIME_FORMAT_AM_PM:
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs), FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale), FALSE);
+		break;
+	case TIME_FORMAT_24_HS:
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm), FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale), FALSE);
+		break;
+	
+	case TIME_FORMAT_LOCALE:
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_am_pm), FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_24_hs), FALSE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->time_format_locale), TRUE);
+		break;
+	
+	
+	}
 
 	g_snprintf(s, sizeof (s), "%s", config_currency_symbol);
 	gtk_entry_set_text(GTK_ENTRY(odlg->currency_symbol), s);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->currency_use_locale),
-                                 config_currency_use_locale);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(odlg->currency_use_locale),
+	                             config_currency_use_locale);
 
 
 	/* set to unmodified as it reflects the current state of the app */
@@ -624,18 +698,21 @@ options_dialog_set(PrefsDialog *odlg)
 
 /* ============================================================== */
 
-static void 
-daystart_menu_changed (gpointer data, GtkOptionMenu *w)
+static void
+daystart_menu_changed (gpointer data, GtkComboBox *w)
 {
 	PrefsDialog *dlg = data;
 
-	int hour = get_optionmenu_item (dlg->daystart_menu);
+	int hour = gtk_combo_box_get_active (dlg->daystart_menu);
+
+	g_return_if_fail (hour >= 0);
+
 	hour += -3;  /* menu starts at 9PM */
 
 	int secs = hour * 3600;
 	if (0 > secs) secs += 24*3600;
 	char buff[24];
-	qof_print_hours_elapsed_buff (buff, 24, secs, config_show_secs);   
+	xxxqof_print_hours_elapsed_buff (buff, 24, secs, config_show_secs);
 	gtk_entry_set_text (dlg->daystart_secs, buff);
 }
 
@@ -661,7 +738,7 @@ daystart_menu_changed (gpointer data, GtkOptionMenu *w)
 	e;                                                              \
 })
 
-static void 
+static void
 display_options(PrefsDialog *dlg)
 {
 	GtkWidget *w;
@@ -685,7 +762,7 @@ display_options(PrefsDialog *dlg)
 	dlg->show_title_##strname = GTK_CHECK_BUTTON(w);
 
 
-static void 
+static void
 field_options(PrefsDialog *dlg)
 {
 	GtkWidget *w;
@@ -712,7 +789,7 @@ field_options(PrefsDialog *dlg)
 }
 
 
-static void 
+static void
 shell_command_options (PrefsDialog *dlg)
 {
 	GtkWidget *e;
@@ -725,7 +802,7 @@ shell_command_options (PrefsDialog *dlg)
 	dlg->shell_stop = GTK_ENTRY(e);
 }
 
-static void 
+static void
 logfile_options(PrefsDialog *dlg)
 {
 	GtkWidget *w;
@@ -740,25 +817,29 @@ logfile_options(PrefsDialog *dlg)
 	w = glade_xml_get_widget (gtxml, "filename label");
 	dlg->logfilename_l = w;
 
-	w = GETWID ("filename combo");
-	dlg->logfilename = GTK_ENTRY(w);
+	w = glade_xml_get_widget (gtxml, "logfile path");
+	dlg->logfilename = GTK_FILE_CHOOSER(w);
+	gtk_signal_connect_object (GTK_OBJECT (dlg->logfilename),
+							   "file-set",
+							   GTK_SIGNAL_FUNC (gnome_property_box_changed),
+							   GTK_OBJECT (dlg->dlg));
 
 	w = glade_xml_get_widget (gtxml, "fstart label");
 	dlg->logfilestart_l = w;
 
-	w = GETWID ("fstart combo");
+	w = GETWID ("fstart");
 	dlg->logfilestart = GTK_ENTRY(w);
 
 	w = glade_xml_get_widget (gtxml, "fstop label");
 	dlg->logfilestop_l = w;
 
-	w = GETWID ("fstop combo");
+	w = GETWID ("fstop");
 	dlg->logfilestop = GTK_ENTRY(w);
 
 	w = glade_xml_get_widget (gtxml, "fmin label");
 	dlg->logfileminsecs_l = w;
 
-	w = GETWID ("fmin combo");
+	w = GETWID ("fmin");
 	dlg->logfileminsecs = GTK_ENTRY(w);
 }
 
@@ -766,7 +847,7 @@ logfile_options(PrefsDialog *dlg)
 	w = GETCHWID ("show " #strname);		\
 	dlg->show_tb_##strname = GTK_CHECK_BUTTON(w);
 
-static void 
+static void
 toolbar_options(PrefsDialog *dlg)
 {
 	GtkWidget *w;
@@ -790,7 +871,7 @@ toolbar_options(PrefsDialog *dlg)
 	TBWID (exit);
 }
 
-static void 
+static void
 misc_options(PrefsDialog *dlg)
 {
 	GtkWidget *w;
@@ -805,59 +886,56 @@ misc_options(PrefsDialog *dlg)
 	w = GETWID ("daystart entry");
 	dlg->daystart_secs = GTK_ENTRY(w);
 
-	w = GETWID ("daystart optionmenu");
-	dlg->daystart_menu = GTK_OPTION_MENU(w);
+	w = GETWID ("daystart combobox");
+	dlg->daystart_menu = GTK_COMBO_BOX(w);
 
 	gtk_signal_connect_object(GTK_OBJECT(w), "changed",
 	                  GTK_SIGNAL_FUNC(daystart_menu_changed),
 	                  dlg);
 
-	w = GETWID ("weekstart optionmenu");
-	dlg->weekstart_menu = GTK_OPTION_MENU(w);
+	w = GETWID ("weekstart combobox");
+	dlg->weekstart_menu = GTK_COMBO_BOX(w);
 }
 
 static void
 time_format_options(PrefsDialog *dlg)
 {
-    GtkWidget *w;
-    GladeXML *gtxml = dlg->gtxml;
+	GtkWidget *w;
+	GladeXML *gtxml = dlg->gtxml;
 
-    w = GETCHWID("time_format_am_pm");
-    dlg->time_format_am_pm = GTK_RADIO_BUTTON(w);
+	w = GETCHWID("time_format_am_pm");
+	dlg->time_format_am_pm = GTK_RADIO_BUTTON(w);
 
-    w = GETCHWID("time_format_24_hs");
-    dlg->time_format_24_hs = GTK_RADIO_BUTTON(w);
+	w = GETCHWID("time_format_24_hs");
+	dlg->time_format_24_hs = GTK_RADIO_BUTTON(w);
 
-    w = GETCHWID("time_format_locale");
-    dlg->time_format_locale = GTK_RADIO_BUTTON(w);
+	w = GETCHWID("time_format_locale");
+	dlg->time_format_locale = GTK_RADIO_BUTTON(w);
 }
 
 static void
 currency_options(PrefsDialog *dlg)
 {
-    GtkWidget *w;
-    GladeXML *gtxml = dlg->gtxml;
+	GtkWidget *w;
+	GladeXML *gtxml = dlg->gtxml;
 
-    w = GETWID ("currency_symbol");
-    dlg->currency_symbol = GTK_ENTRY(w);
+	w = GETWID ("currency_symbol");
+	dlg->currency_symbol = GTK_ENTRY(w);
 
 	w = glade_xml_get_widget (gtxml, "currency_symbol_label");
 	dlg->currency_symbol_label = w;
 
-
-    w = GETCHWID ("currency_use_locale");
-    dlg->currency_use_locale = GTK_ENTRY(w);
+	w = GETCHWID ("currency_use_locale");
+	dlg->currency_use_locale = GTK_CHECK_BUTTON(w);
 
 	gtk_signal_connect(GTK_OBJECT(w), "clicked",
-                       GTK_SIGNAL_FUNC(currency_sensitive_cb),
-                       (gpointer *)dlg);
-
-
+	                   GTK_SIGNAL_FUNC(currency_sensitive_cb),
+	                   (gpointer *)dlg);
 }
 
 /* ============================================================== */
 
-static void 
+static void
 help_cb (GnomePropertyBox *propertybox, gint page_num, gpointer data)
 {
 	gtt_help_popup (GTK_WIDGET(propertybox), data);
@@ -891,8 +969,8 @@ prefs_dialog_new (void)
 	logfile_options (dlg);
 	toolbar_options (dlg);
 	misc_options (dlg);
-    time_format_options (dlg);
-    currency_options (dlg);
+	time_format_options (dlg);
+	currency_options (dlg);
 
 	gnome_dialog_close_hides(GNOME_DIALOG(dlg->dlg), TRUE);
 	return dlg;
@@ -903,11 +981,11 @@ prefs_dialog_new (void)
 
 static PrefsDialog *dlog = NULL;
 
-void 
+void
 prefs_dialog_show(void)
 {
 	if (!dlog) dlog = prefs_dialog_new();
- 
+
 	options_dialog_set (dlog);
 	gtk_widget_show(GTK_WIDGET(dlog->dlg));
 }
