@@ -20,13 +20,12 @@
 #include "config.h"
 
 #include <glib.h>
-/* #include <gnome.h>  */  /* only needed for definition of _() */
 #include <libintl.h> /*conflicts with <libgnome/gnome-i18n.h> on some systems */
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
-#include <qof/qof.h>
+#include <qof.h>
 
 #include "err-throw.h"
 #include "log.h"
@@ -893,6 +892,35 @@ gtt_project_insert_after(GttProject *p, GttProject *after_me)
 	}
 }
 
+void
+gtt_project_reparent (GttProject *proj, GttProject *parent, int position)
+{
+	GList **new_list = NULL;
+	GList **old_list = NULL;
+	if (parent)
+	{
+		new_list = &parent->sub_projects;
+	}
+	else
+	{
+		new_list = &global_plist->prj_list;
+	}
+
+	if (proj->parent)
+	{
+		old_list = &proj->parent->sub_projects;
+	}
+	else
+	{
+		old_list = &global_plist->prj_list;
+	}
+
+	*old_list = g_list_remove (*old_list, proj);
+	*new_list = g_list_insert (*new_list, proj, position);
+	proj->parent = parent;
+
+}
+
 
 void
 gtt_project_append_task (GttProject *proj, GttTask *task)
@@ -934,6 +962,7 @@ gtt_project_prepend_task (GttProject *proj, GttTask *task)
 	}
 
 	proj->task_list = g_list_prepend (proj->task_list, task);
+	proj->current_task = task;
 	task->parent = proj;
 
 	if (is_running) gtt_project_timer_start (proj);
@@ -971,6 +1000,30 @@ gtt_project_get_first_task (GttProject *proj)
 	return (proj->task_list->data);
 }
 
+GttTask *
+gtt_project_get_current_task (GttProject *proj)
+{
+	if (!proj) return NULL;
+	if (!proj->current_task)
+		return gtt_project_get_first_task(proj);
+
+	return (proj->current_task);
+}
+
+void
+gtt_project_set_current_task (GttProject *proj, GttTask *newCurrentTask)
+{
+	int is_running = 0;
+
+	if (!proj || !newCurrentTask) return;
+
+	if (proj->current_task)
+		is_running = task_suspend(proj->current_task);
+	proj->current_task = newCurrentTask;
+	if (is_running) gtt_project_timer_start(proj);
+	proj_refresh_time(proj);
+}
+
 GttInterval *
 gtt_project_get_first_interval (GttProject *proj)
 {
@@ -1191,7 +1244,7 @@ gtt_project_get_secs_current (GttProject *proj)
 	GttTask *tsk;
 	if (!proj) return 0;
 	if (!proj->task_list) return 0;
-	tsk = proj->task_list->data;
+	tsk = gtt_project_get_current_task (proj);
 
 	return gtt_task_get_secs_ever(tsk);
 }
@@ -1763,17 +1816,28 @@ gtt_project_timer_start (GttProject *proj)
 
 	if (!proj) return;
 
-	/* By definition, the current task is the one at the head
-	 * of the list, and the current interval is  at the head
+	/* By definition, the current task is not anymore the one at the head
+	 * of the list, but rather the one denoted by GttProject->current_task
+	 * and the current interval is  at the head
 	 * of the task */
 	if (NULL == proj->task_list)
 	{
 		task = gtt_task_new();
 		gtt_task_set_memo (task, _("New Diary Entry"));
+		proj->current_task = task;
 	}
 	else
 	{
-		task = proj->task_list->data;
+		if (NULL == proj->current_task)
+		{
+			task = proj->task_list->data;
+			proj->current_task = task;
+		}
+		else
+		{
+			task = proj->current_task;
+		}
+
 		g_return_if_fail (task);
 	}
 
@@ -1821,11 +1885,13 @@ gtt_project_timer_update (GttProject *proj)
 
 	if (!proj) return;
 	g_return_if_fail (proj->task_list);
+	g_return_if_fail (proj->current_task);
 
-	/* by definition, the current task is the one at the head
-	 * of the list, and the current interval is at the head
+	/* By definition, the current task is not anymore the one at the head
+	 * of the list, but rather the one denoted by GttProject->current_task
+	 * and the current interval is  at the head
 	 * of the task */
-	task = proj->task_list->data;
+	task = proj->current_task;
 	g_return_if_fail (task);
 
 	/* Its possible that there are no intervals (which implies
@@ -1862,12 +1928,12 @@ gtt_project_timer_stop (GttProject *proj)
 	GttInterval *ival;
 
 	if (!proj) return;
-	if (!proj->task_list) return;
+	if (!proj->current_task) return;
 
 	gtt_project_timer_update (proj);
 
 	/* Also note that the timer really has stopped. */
-	task = proj->task_list->data;
+	task = proj->current_task;
 	g_return_if_fail (task);
 
 	/* its 'legal' to have no intervals, which implies
@@ -1898,8 +1964,7 @@ prj_obj_foreach_helper (GList *prjlist, QofEntityForeachCB cb, gpointer data)
 	for (node=prjlist; node; node=node->next)
 	{
 		GttProject *prj = node->data;
-		void (*ncb) (GttProject *, void *) = (void (*) (GttProject *, void *)) cb;
-		ncb (prj, data);
+		cb ((QofEntity *) prj, data);
 		prj_obj_foreach_helper (prj->sub_projects, cb, data);
 	}
 }
@@ -1932,20 +1997,25 @@ printable:         NULL,
 
 /* =========================================================== */
 /* bogus wrappers */
-static Timespec
-prj_obj_get_earliest (GttProject *prj)
+static QofTime *
+prj_obj_get_earliest (GttProject *prj, QofParam *qpm)
 {
-	Timespec ts = {0,0};
-	ts.tv_sec = gtt_project_get_earliest_start (prj, TRUE);
-	return ts;
+	// static time return, not thread safe, but a hack that will do for now.
+	static QofTime *qt = NULL;
+	if (NULL == qt) qt = qof_time_new();
+	time_t gt = gtt_project_get_earliest_start (prj, TRUE);
+	qof_time_set_secs (qt, gt);
+	return qt;
 }
 
-static Timespec
-prj_obj_get_latest (GttProject *prj)
+static QofTime *
+prj_obj_get_latest (GttProject *prj, QofParam *qpm)
 {
-	Timespec ts = {0,0};
-	ts.tv_sec = gtt_project_get_latest_stop (prj, TRUE);
-	return ts;
+	static QofTime *qt = NULL;
+	if (NULL == qt) qt = qof_time_new();
+	time_t gt = gtt_project_get_latest_stop (prj, TRUE);
+	qof_time_set_secs (qt, gt);
+	return qt;
 }
 
 gboolean
@@ -1955,8 +2025,8 @@ gtt_project_obj_register (void)
 
 /* Associate an ASCII name to each getter, as well as the return type */
 static QofParam params[] = {
-		{ GTT_PROJECT_EARLIEST, QOF_TYPE_DATE, (QofAccessFunc)prj_obj_get_earliest, NULL},
-		{ GTT_PROJECT_LATEST, QOF_TYPE_DATE, (QofAccessFunc)prj_obj_get_latest, NULL},
+		{ GTT_PROJECT_EARLIEST, QOF_TYPE_TIME, (QofAccessFunc)prj_obj_get_earliest, NULL},
+		{ GTT_PROJECT_LATEST, QOF_TYPE_TIME, (QofAccessFunc)prj_obj_get_latest, NULL},
 		{ NULL },
 	};
 
@@ -2071,12 +2141,16 @@ gtt_task_remove (GttTask *task)
 
 	is_running = task_suspend (task);
 
-	if (task->parent)
+	GttProject *project = task->parent;
+
+	if (project)
 	{
-		task->parent->task_list =
-			g_list_remove (task->parent->task_list, task);
-		if (is_running) gtt_project_timer_start (task->parent);
-		proj_refresh_time (task->parent);
+		project->task_list =
+			g_list_remove (project->task_list, task);
+		gtt_project_set_current_task(project,
+				gtt_project_get_first_task(project));
+		if (is_running) gtt_project_timer_start (project);
+		proj_refresh_time (project);
 		task->parent = NULL;
 	}
 }
@@ -2134,6 +2208,7 @@ gtt_task_new_insert (GttTask *old)
 
 	idx = g_list_index (prj->task_list, old);
 	prj->task_list = g_list_insert (prj->task_list, task, idx);
+	prj->current_task = task;
 
 	if (is_running) gtt_project_timer_start (prj);
 	proj_refresh_time (prj);
