@@ -21,7 +21,7 @@
 #define __GTT_PROJ_H__
 
 #include <glib.h>
-#include <qof/qof.h>
+#include <qof.h>
 
 /* The data structures for GnoTime are written in a quasi-object-oriented
  * style.  All data is encapsulated in opaque structs, and can be accessed
@@ -92,12 +92,19 @@ typedef enum
 #define GTT_PROJECT_ID "GttProjectId"
 #define GTT_TASK_ID    "GttTaskId"
 
-#define GTT_PROJECT_EARLIEST "GttProjectEarliet"
+#define GTT_PROJECT_EARLIEST "GttProjectEarliest"
 #define GTT_PROJECT_LATEST   "GttProjectLatest"
 
 /* -------------------------------------------------------- */
 /* The four basic structures */
 typedef struct gtt_project_list_s GttProjectList;
+
+/* This is a temporary hack so we can get a handle
+to the project list in app.c
+   XXX should be fixed soon.
+*/
+extern GttProjectList *global_plist;
+
 typedef struct gtt_project_s GttProject;
 typedef struct gtt_task_s GttTask;
 typedef struct gtt_interval_s GttInterval;
@@ -375,6 +382,8 @@ int      gtt_project_total (GttProject *);
 GList       * gtt_project_get_children (GttProject *);
 GList       * gtt_project_get_tasks (GttProject *);
 GttTask     * gtt_project_get_first_task (GttProject *);
+GttTask     * gtt_project_get_current_task (GttProject *);
+void          gtt_project_set_current_task (GttProject *proj, GttTask *tsk);
 GttInterval * gtt_project_get_first_interval (GttProject *);
 
 GttProject * 	gtt_project_get_parent (GttProject *);
@@ -411,6 +420,8 @@ void	gtt_project_append_project (GttProject *parent, GttProject *child);
 void	gtt_project_insert_before (GttProject *proj, GttProject *before_me);
 void	gtt_project_insert_after (GttProject *proj, GttProject *after_me);
 
+void    gtt_project_reparent (GttProject *proj, GttProject *parent, int position);
+
 void	gtt_project_append_task (GttProject *, GttTask *);
 void	gtt_project_prepend_task (GttProject *, GttTask *);
 
