@@ -1,29 +1,29 @@
 /*********************************************************************
- *                
- * Copyright (C) 2007,  Goedson Teixeira Paixao
- *                
+ *
+ * Copyright (C) 2007, 2009,  Goedson Teixeira Paixao
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 3
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA.
- *                
+ *
  * Filename:      projects-tree.c
  * Author:        Goedson Teixeira Paixao <goedson@debian.org>
  * Description:   Implementation of the ProjectsTree component for
  *                Gnotime
- *                
+ *
  * Created at:    Thu Nov 22 18:23:49 2007
- * Modified at:   Sat Dec  1 17:56:41 2007
+ * Modified at:   Tue Nov 24 23:11:33 2009
  * Modified by:   Goedson Teixeira Paixao <goedson@debian.org>
  ********************************************************************/
 
@@ -266,7 +266,7 @@ gtt_projects_tree_init (GttProjectsTree* gpt)
 	priv->column_definitions[8].default_width = 72;
 
 	priv->column_definitions[9].name = "description";
-	priv->column_definitions[9].model_column = TITLE_COLUMN;
+	priv->column_definitions[9].model_column = DESCRIPTION_COLUMN;
 	priv->column_definitions[9].renderer = priv->text_renderer;
 	priv->column_definitions[9].value_property_name = "text";
 	priv->column_definitions[9].label = _("Description");
@@ -379,7 +379,7 @@ gtt_projects_tree_class_init (GttProjectsTreeClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gtt_projects_tree_finalize;
 	g_type_class_add_private (object_class, sizeof (GttProjectsTreePrivate));
-	projects_tree_signals[COLUMNS_SETUP_DONE] = 
+	projects_tree_signals[COLUMNS_SETUP_DONE] =
 		g_signal_new ("columns_setup_done",
 					  G_TYPE_FROM_CLASS (object_class),
 					  G_SIGNAL_RUN_LAST,
@@ -564,7 +564,7 @@ gtt_projects_tree_set_project_data (GttProjectsTree *gpt, GtkTreeStore *tree_mod
 						iter,
 						TITLE_COLUMN, gtt_project_get_title (prj),
 						DESCRIPTION_COLUMN, gtt_project_get_desc (prj),
-						TASK_COLUMN, gtt_task_get_memo (gtt_project_get_first_task (prj)),
+						TASK_COLUMN, gtt_task_get_memo (gtt_project_get_current_task (prj)),
 						SIZING_COLUMN, gtt_project_get_sizing (prj),
 						PERCENT_COLUMN, gtt_project_get_percent_complete (prj),
 						GTT_PROJECT_COLUMN, prj,
@@ -690,7 +690,10 @@ gtt_projects_tree_set_visible_columns (GttProjectsTree *project_tree,
 	GList *p;
 	GttProjectsTreePrivate *priv = GTT_PROJECTS_TREE_GET_PRIVATE (project_tree);
 
-	g_tree_destroy (priv->column_references);
+	if (priv->column_references)
+	{
+		g_tree_destroy (priv->column_references);
+	}
 	priv->column_references = g_tree_new ((GCompareFunc) strcmp);
 
 
@@ -701,7 +704,7 @@ gtt_projects_tree_set_visible_columns (GttProjectsTree *project_tree,
 	}
 
 
-	/* The title column is mandatory. If it's not on the list, 
+	/* The title column is mandatory. If it's not on the list,
 	   we add it as the first column. */
 
 	if (!g_list_find_custom (columns, "title", (GCompareFunc) strcmp))
@@ -1069,7 +1072,7 @@ gtt_projects_tree_model_row_changed_callback (GtkTreeModel *model,
 		{
 			GtkTreePath *ref_path = gtk_tree_row_reference_get_path (row_ref);
 
-			/* If the row has been moved around we reparent it and 
+			/* If the row has been moved around we reparent it and
 			   update its row reference */
 			if (gtk_tree_path_compare (path, ref_path))
 			{
@@ -1155,6 +1158,7 @@ set_expander_state (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, g
 void
 gtt_projects_tree_set_expander_state (GttProjectsTree *gpt, gchar *states)
 {
+	g_return_if_fail(states != NULL);
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (gpt));
 	ExpanderStateHelper esh;
 	int row = 0;
@@ -1163,7 +1167,6 @@ gtt_projects_tree_set_expander_state (GttProjectsTree *gpt, gchar *states)
 	esh.row = &row;
 	esh.view = GTK_TREE_VIEW (gpt);
 
-
 	gtk_tree_model_foreach (model, set_expander_state, &esh);
 }
 
@@ -1216,7 +1219,7 @@ gtt_projects_tree_set_sorted_column (GttProjectsTree *gpt, GtkTreeViewColumn *co
 		{
 			gtk_tree_view_column_set_sort_indicator (GTK_TREE_VIEW_COLUMN(p->data), TRUE);
 			gtk_tree_view_column_set_sort_order (GTK_TREE_VIEW_COLUMN(p->data), GTK_SORT_ASCENDING);
-		} 
+		}
 		else
 		{
 			gtk_tree_view_column_set_sort_indicator (GTK_TREE_VIEW_COLUMN(p->data), FALSE);
