@@ -1,4 +1,4 @@
-/* Low-level timer callbacks & timeout handlers for GTimeTracker 
+/* Low-level timer callbacks & timeout handlers for GTimeTracker
  * Copyright (C) 1997,98 Eckehard Berns
  * Copyright (C) 2001,2002, 2003 Linas Vepstas <linas@linas.org>
  *
@@ -174,7 +174,7 @@ stop_main_timer (void)
 void
 init_timer(void)
 {
-	g_return_if_fail (!timer_inited);
+	if (timer_inited) return;   // prevent multiple initialization
 	timer_inited = TRUE;
 
 	idle_dialog = idle_dialog_new();
@@ -213,7 +213,7 @@ start_no_project_timer (void)
 	{
 		init_timer();
 	}
-	if (!idle_dialog_is_visible (idle_dialog) && timer_is_running ())
+	if (!idle_dialog_is_visible (idle_dialog) && !timer_is_running ())
 	{
 		idle_dialog_deactivate_timer (idle_dialog);
 		active_dialog_activate_timer (active_dialog);
